@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 
 """
-test_django-charts
+test_dj-chartjs
 ------------
 
-Tests for `django-charts` models module.
+Tests for `dj-chartjs` models module.
 """
 
 from django.test import TestCase
@@ -14,7 +14,6 @@ from dj_chartjs import models
 
 
 class TestDj_chartjs(TestCase):
-
     def setUp(self):
         pass
 
